Coverage for /Users/sebastiana/Documents/Sugarpills/confidence/spotify_confidence/chartgrid.py: 44%

1# Copyright 2017-2020 Spotify AB

2#

3# Licensed under the Apache License, Version 2.0 (the "License");

4# you may not use this file except in compliance with the License.

5# You may obtain a copy of the License at

6#

7# http://www.apache.org/licenses/LICENSE-2.0

8#

9# Unless required by applicable law or agreed to in writing, software

10# distributed under the License is distributed on an "AS IS" BASIS,

11# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

12# See the License for the specific language governing permissions and

13# limitations under the License.

14

15# TODO: Move this to chartify.

16 from typing import Iterable

17

18

19 class ChartGrid:

20 """Collection of chartify.Chart objects

21

22 Properties

23 - .charts: List of chartify Charts.

24 - .show(): Render all the charts.

25 """

26

27 def __init__(self, charts: Iterable = None):

28 if charts is None:

29 charts = []

30 self.charts = charts

31

32 def show(self, format="html"):

33 for chart in self.charts:

34 chart.show(format=format)